@@ -6,7 +6,7 @@ from testpath import assert_isfile
 from unittest.mock import patch
 import pytest
 
-import pytoml
+import toml
 
 from flit import init
 
@@ -107,9 +107,8 @@ def test_init():
         generated = Path(td) / 'pyproject.toml'
         assert_isfile(generated)
         with generated.open() as f:
-            data = pytoml.load(f)
-        assert data['tool']['flit']['metadata'][
-                   'author-email'] == "test@example.com"
+            data = toml.load(f)
+        assert data['project']['authors'][0]['email'] == "test@example.com"
         license = Path(td) / 'LICENSE'
         assert_isfile(license)
         with license.open() as f:
@@ -131,13 +130,12 @@ def test_init_homepage_and_license_are_optional():
         ti = init.TerminalIniter(td)
         ti.initialise()
         with Path(td, 'pyproject.toml').open() as f:
-            data = pytoml.load(f)
+            data = toml.load(f)
         assert not Path(td, 'LICENSE').exists()
-    metadata = data['tool']['flit']['metadata']
-    assert metadata == {
-        'author': 'Test Author',
-        'author-email': 'test_email@example.com',
-        'module': 'test_module_name',
+    assert data['project'] == {
+        'authors': [{'name': 'Test Author', 'email': 'test_email@example.com'}],
+        'name': 'test_module_name',
+        'dynamic': ['version', 'description'],
     }
 
 def test_init_homepage_validator():
@@ -154,13 +152,12 @@ def test_init_homepage_validator():
         ti = init.TerminalIniter(td)
         ti.initialise()
         with Path(td, 'pyproject.toml').open() as f:
-            data = pytoml.load(f)
-    metadata = data['tool']['flit']['metadata']
-    assert metadata == {
-        'author': 'Test Author',
-        'author-email': 'test_email@example.com',
-        'home-page': 'https://www.example.org',
-        'module': 'test_module_name',
+            data = toml.load(f)
+    assert data['project'] == {
+        'authors': [{'name': 'Test Author', 'email': 'test_email@example.com'}],
+        'name': 'test_module_name',
+        'urls': {'Home': 'https://www.example.org'},
+        'dynamic': ['version', 'description'],
     }
 
 def test_author_email_field_is_optional():
@@ -176,13 +173,14 @@ def test_author_email_field_is_optional():
         ti = init.TerminalIniter(td)
         ti.initialise()
         with Path(td, 'pyproject.toml').open() as f:
-            data = pytoml.load(f)
+            data = toml.load(f)
         assert not Path(td, 'LICENSE').exists()
-    metadata = data['tool']['flit']['metadata']
-    assert metadata == {
-        'author': 'Test Author',
-        'module': 'test_module_name',
-        'home-page': 'https://www.example.org',
+
+    assert data['project'] == {
+        'authors': [{'name': 'Test Author'}],
+        'name': 'test_module_name',
+        'urls': {'Home': 'https://www.example.org'},
+        'dynamic': ['version', 'description'],
     }
 
 
@@ -216,12 +214,11 @@ def test_init_readme_found_yes_choosen():
         ti = init.TerminalIniter(td)
         ti.initialise()
         with Path(td, 'pyproject.toml').open() as f:
-            data = pytoml.load(f)
+            data = toml.load(f)
 
-    metadata = data['tool']['flit']['metadata']
-    assert metadata == {
-        'author': 'Test Author',
-        'author-email': 'test_email@example.com',
-        'module': 'test_module_name',
-        'description-file': 'readme.md'
+    assert data['project'] == {
+        'authors': [{'name': 'Test Author', 'email': 'test_email@example.com'}],
+        'name': 'test_module_name',
+        'readme': 'readme.md',
+        'dynamic': ['version', 'description'],
     }
