@@ -1,6 +1,6 @@
 import os
 from pathlib import Path
-import pytoml
+import toml
 from shutil import copy
 from testpath import assert_isfile
 
@@ -18,7 +18,7 @@ def test_tomlify(copy_sample, monkeypatch):
     assert_isfile(pyproject_toml)
 
     with pyproject_toml.open(encoding='utf-8') as f:
-        content = pytoml.load(f)
+        content = toml.load(f)
 
     assert 'build-system' in content
     assert 'tool' in content
